Installation
============

The **aas-timeseries** package requires Python 3.6 or later. To install the
latest version of aas-timeseries as well as its dependencies, you can
do::

    pip install aas-timeseries

If you want to install the latest developer version, you can instead use::

    pip install git+https://github.com/aperiosoftware/aas-timeseries
